searchNodes=[{"ref":"Cldr.Print.html","title":"Cldr.Print","type":"module","doc":"Implements printf/3, sprintf/3 and lprintf/3 in a manner largely compatible with the standard C language implementations."},{"ref":"Cldr.Print.html#lprintf/3","title":"Cldr.Print.lprintf/3","type":"function","doc":"Returns an {:ok, io_list} after applying a format to a list of arguments. The arguments and options are the same as those for printf/3"},{"ref":"Cldr.Print.html#lprintf!/3","title":"Cldr.Print.lprintf!/3","type":"function","doc":"Returns an io_list or raises after applying a format to a list of arguments. The arguments and options are the same as those for printf/3"},{"ref":"Cldr.Print.html#printf/3","title":"Cldr.Print.printf/3","type":"function","doc":"Formats and prints its arguments under control of a format. The format is a character string which contains two types of objects: plain characters, which are simply copied to standard output and format specifications, each of which causes printing of the next successive argument. Arguments format is a format string. Information on the definition of a format string is below. args is a list of arguments that are formatted according to the directives in the format string. The number of args in the list must be at least equal to the number of format specifiers in the format string. options is a keyword list defining how the number is to be formatted. The valid options are: Options backend is any Cldr backend. That is, any module that contains use Cldr. The default is the included Cldr.Print.Backend which is configured with only the locale en. :rounding_mode: determines how a number is rounded to meet the precision of the format requested. The available rounding modes are :down, :half_up, :half_even, :ceiling, :floor, :half_down, :up. The default is :half_even. :number_system: determines which of the number systems for a locale should be used to define the separators and digits for the formatted number. If number_system is an atom then number_system is interpreted as a number system. See Cldr.Number.System.number_systems_for/2. If the :number_system is binary then it is interpreted as a number system name. See Cldr.Number.System.number_system_names_for/2. The default is :default. :locale: determines the locale in which the number is formatted. See Cldr.known_locale_names/0. The default isCldr.get_locale/0 which is the locale currently in affect for this Process and which is set by Cldr.put_locale/1. :device which is used to define the output device for printf/3. The default is :stdout. Returns :ok on success {:error, {exception, reason}} if an error is detected Format definition Each format specification is introduced by the percent character (%). The remainder of the format specification includes, in the following order: Optional format flags Optional field width Optional precision Required format type The can be represented as: %[flags][width][.precision]format_type Format flags Zero or more of the following flags: FlagDescription #A # character specifying that the value should be printed in an alternate form. For b, c, d, s and u formats, this option has no effect. For the o formats the precision of the number is increased to force the first character of the output string to a zero. For the x (X) format, a non-zero result has the string 0x (0X) prepended to it. For a, A, e, E, f, F, g and G formats, the result will always contain a decimal point, even if no digits follow the point (normally, a decimal point only appears in the results of those formats if a digit follows the decimal point). For g and G formats, trailing zeros are not removed from the result as they would otherwise be. -A minus sign `-&#39; which specifies left adjustment of the output in the indicated field. +A + character specifying that there should always be a sign placed before the number when using signed formats. spaceA space character specifying that a blank should be left before a positive number for a signed format. A + overrides a space if both are used. 0A zero 0 character indicating that zero-padding should be used rather than blank-padding. A - overrides a 0 if both are used. &#39;Formats a number with digit grouping applied. The group size and grouping character are determined based upon the current processes locale or the :locale option to printf/3 if provided. IFormats a number using the native number system digits of the current processes locale or the :locale option to printf/3 if provided. The option :number_system if provided takes precedence over this flag. Field Width An optional digit string specifying a field width; if the output string has fewer bytes than the field width it will be blank-padded on the left (or right, if the left-adjustment indicator has been given) to make up the field width (note that a leading zero is a flag, but an embedded zero is part of a field width). Precision An optional period, ., followed by an optional digit string giving a precision which specifies the number of digits to appear after the decimal point, for e and f formats, or the maximum number of graphemes to be printed from a string. If the digit string is missing, the precision is treated as zero. Format Type A character which indicates the type of format to use (one of diouxXfFeEgGaAs). The uppercase formats differ from their lowercase counterparts only in that the output of the former is entirely in uppercase. FormatDescription diouXxThe argument is printed as a signed decimal (d or i), unsigned octal, unsigned decimal, or unsigned hexadecimal (X or x), respectively. fFThe argument is printed in the style [-]ddd.ddd where the number of d&#39;s after the decimal point is equal to the precision specification for the argument. If the precision is missing, 6 digits are given; if the precision is explicitly 0, no digits and no decimal point are printed. The values infinity and NaN are printed as inf&#39; andnan&#39;, respectively. eEThe argument is printed in the style e [-d.ddd+-dd] where there is one digit before the decimal point and the number after is equal to the precision specification for the argument; when the precision is missing, 6 digits are produced. The values infinity and NaN are printed as inf and nan, respectively. gGThe argument is printed in style f or e (or in style E for a G format code), with the precision specifying the number of significant digits. The style used depends on the value converted: style e will be used only if the exponent resulting from the conversion is less than -4 or greater than the precision. Trailing zeroes are removed from the result; a decimal point appears only if it is followed by a digit. aAThe argument is printed in style [-h.hhh+-pd] where there is one digit before the hexadecimal point and the number after is equal to the precision specification for the argument; when the precision is missing, enough digits are produced to convey the argument&#39;s exact double-precision floating-point representation. The values infinity and NaN are printed as inf and nan, respectively. sGraphemes from the string argument are printed until the end is reached or until the number of graphemes indicated by the precision specification is reached; however if the precision is 0 or missing, the string is printed entirely. %Print a %; no argument is used. Notes The grouping separator, decimal point and exponent characters are defined in the current processes locale or as specified in the :locale option to printf/3. In no case does a non-existent or small field width cause truncation of a field; padding takes place only if the specified field width exceeds the actual width. printf/3 calls IO.write/2 and therefore there are no control characters emitted unless provided in the format string. This is consisten with the C implementation but different from IO.puts/2."},{"ref":"Cldr.Print.html#sprintf/3","title":"Cldr.Print.sprintf/3","type":"function","doc":"Returns a {:ok, string} after applying a format to a list of arguments. The arguments and options are the same as those for printf/3"},{"ref":"Cldr.Print.html#sprintf!/3","title":"Cldr.Print.sprintf!/3","type":"function","doc":"Returns a string or raises after applying a format to a list of arguments. The arguments and options are the same as those for printf/3"},{"ref":"Cldr.Print.Backend.html","title":"Cldr.Print.Backend","type":"module","doc":"Provides the core functions to retrieve and manage the CLDR data that supports formatting and localisation. It provides the core functions to access formatted CLDR data, set and retrieve a current locale and validate certain core data types such as locales, currencies and territories."},{"ref":"Cldr.Print.Backend.html#available_locale_name?/1","title":"Cldr.Print.Backend.available_locale_name?/1","type":"function","doc":"See Cldr.available_locale_name?/1."},{"ref":"Cldr.Print.Backend.html#default_locale/0","title":"Cldr.Print.Backend.default_locale/0","type":"function","doc":"Returns the default locale. Example iex&gt; Cldr.Print.Backend.default_locale() %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-001&quot;, cldr_locale_name: &quot;en-001&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en-001&quot;, script: &quot;Latn&quot;, territory: &quot;001&quot;, transform: %{}, language_variant: nil }"},{"ref":"Cldr.Print.Backend.html#default_territory/0","title":"Cldr.Print.Backend.default_territory/0","type":"function","doc":"Returns the default territory when a locale does not specify one and none can be inferred. Example iex&gt; Cldr.Print.Backend.default_territory() :&quot;001&quot;"},{"ref":"Cldr.Print.Backend.html#ellipsis/2","title":"Cldr.Print.Backend.ellipsis/2","type":"function","doc":"Add locale-specific ellipsis to a string. Arguments string is any valid Elixir string backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend/0. Note that Cldr.default_backend/0 will raise an exception if no :default_backend is configured under the :ex_cldr key in config.exs. options is a keyword list of options Options :locale is any valid locale name returned by Cldr.known_locale_names/1. The default is Cldr.get_locale/0 :location determines where to place the ellipsis. The options are :after (the default for a single string argument), :between (the default and only valid location for an argument that is a list of two strings) and :before Examples iex&gt; Cldr.Print.Backend.ellipsis &quot;And furthermore&quot; &quot;And furthermore…&quot; iex&gt; Cldr.Print.Backend.ellipsis [&quot;And furthermore&quot;, &quot;there is much to be done&quot;], locale: &quot;ja&quot; &quot;And furthermore…there is much to be done&quot;"},{"ref":"Cldr.Print.Backend.html#get_locale/0","title":"Cldr.Print.Backend.get_locale/0","type":"function","doc":"Return the current locale to be used for Cldr functions that take an optional locale parameter for which a locale is not supplied. Example iex&gt; Cldr.Print.Backend.put_locale(&quot;pl&quot;) iex&gt; Cldr.Print.Backend.get_locale %Cldr.LanguageTag{ canonical_locale_name: &quot;pl-Latn-PL&quot;, cldr_locale_name: &quot;pl&quot;, extensions: %{}, language: &quot;pl&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;pl&quot;, territory: &quot;PL&quot;, requested_locale_name: &quot;pl&quot;, script: &quot;Latn&quot;, transform: %{}, language_variant: nil }"},{"ref":"Cldr.Print.Backend.html#known_calendars/0","title":"Cldr.Print.Backend.known_calendars/0","type":"function","doc":"See Cldr.known_calendars/0."},{"ref":"Cldr.Print.Backend.html#known_currencies/0","title":"Cldr.Print.Backend.known_currencies/0","type":"function","doc":"See Cldr.known_currencies/0."},{"ref":"Cldr.Print.Backend.html#known_gettext_locale_name/1","title":"Cldr.Print.Backend.known_gettext_locale_name/1","type":"function","doc":"Returns either the Gettext locale_name in Cldr format or false based upon whether the locale name is configured in Gettext. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_gettext_locale_names/0 Examples iex&gt; Cldr.Print.Backend.known_gettext_locale_name &quot;en&quot; &quot;en&quot; iex&gt; Cldr.Print.Backend.known_gettext_locale_name &quot;en-SA&quot; false"},{"ref":"Cldr.Print.Backend.html#known_gettext_locale_name?/1","title":"Cldr.Print.Backend.known_gettext_locale_name?/1","type":"function","doc":"Returns a boolean indicating if the specified locale name is configured and available in Gettext. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 Examples iex&gt; Cldr.Print.Backend.known_gettext_locale_name?(&quot;en&quot;) true iex&gt; Cldr.Print.Backend.known_gettext_locale_name?(&quot;!!&quot;) false"},{"ref":"Cldr.Print.Backend.html#known_gettext_locale_names/0","title":"Cldr.Print.Backend.known_gettext_locale_names/0","type":"function","doc":"Returns a list of GetText locale names but in CLDR format with underscore replaced by hyphen in order to facilitate comparisons with Cldr locale names."},{"ref":"Cldr.Print.Backend.html#known_locale_name/1","title":"Cldr.Print.Backend.known_locale_name/1","type":"function","doc":"Returns either the locale_name or false based upon whether the locale name is configured in Cldr. This is helpful when building a list of or expressions to return the first known locale name from a list. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 Examples iex&gt; Cldr.Print.Backend.known_locale_name &quot;en-AU&quot; &quot;en-AU&quot; iex&gt; Cldr.Print.Backend.known_locale_name &quot;en-SA&quot; false"},{"ref":"Cldr.Print.Backend.html#known_locale_name?/1","title":"Cldr.Print.Backend.known_locale_name?/1","type":"function","doc":"Returns a boolean indicating if the specified locale name is configured and available in Cldr. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 Examples iex&gt; Cldr.Print.Backend.known_locale_name?(&quot;en&quot;) true iex&gt; Cldr.Print.Backend.known_locale_name?(&quot;!!&quot;) false"},{"ref":"Cldr.Print.Backend.html#known_locale_names/0","title":"Cldr.Print.Backend.known_locale_names/0","type":"function","doc":"Returns a list of the known locale names. Known locales are those locales which are the subset of all CLDR locales that have been configured for use either in this module or in Gettext."},{"ref":"Cldr.Print.Backend.html#known_number_system_types/0","title":"Cldr.Print.Backend.known_number_system_types/0","type":"function","doc":"Returns a list of atoms representing the number systems types known to Cldr. Example iex&gt; Cldr.Print.Backend.known_number_system_types [:default, :finance, :native, :traditional]"},{"ref":"Cldr.Print.Backend.html#known_number_systems/0","title":"Cldr.Print.Backend.known_number_systems/0","type":"function","doc":"See Cldr.known_number_systems/0."},{"ref":"Cldr.Print.Backend.html#known_rbnf_locale_name/1","title":"Cldr.Print.Backend.known_rbnf_locale_name/1","type":"function","doc":"Returns either the RBNF locale_name or false based upon whether the locale name is configured in Cldr and has RBNF rules defined. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 Examples iex&gt; Cldr.Print.Backend.known_rbnf_locale_name &quot;en&quot; &quot;en&quot; iex&gt; Cldr.Print.Backend.known_rbnf_locale_name &quot;en-SA&quot; false"},{"ref":"Cldr.Print.Backend.html#known_rbnf_locale_name?/1","title":"Cldr.Print.Backend.known_rbnf_locale_name?/1","type":"function","doc":"Returns a boolean indicating if the specified locale name is configured and available in Cldr and supports rules based number formats (RBNF). Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 Examples iex&gt; Cldr.Print.Backend.known_rbnf_locale_name?(&quot;en&quot;) true iex&gt; Cldr.Print.Backend.known_rbnf_locale_name?(&quot;!!&quot;) false"},{"ref":"Cldr.Print.Backend.html#known_rbnf_locale_names/0","title":"Cldr.Print.Backend.known_rbnf_locale_names/0","type":"function","doc":"Returns a list of locale names which have rules-based number formats (RBNF)."},{"ref":"Cldr.Print.Backend.html#known_territories/0","title":"Cldr.Print.Backend.known_territories/0","type":"function","doc":"See Cldr.known_territories/0."},{"ref":"Cldr.Print.Backend.html#put_locale/1","title":"Cldr.Print.Backend.put_locale/1","type":"function","doc":"Set the current locale to be used for Cldr functions that take an optional locale parameter for which a locale is not supplied. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/1 See rfc5646 for the specification of a language tag and consult Cldr.Rfc5646.Parser for the specification as implemented that includes the CLDR extensions for &quot;u&quot; (locales) and &quot;t&quot; (transforms). Examples iex&gt; Cldr.Print.Backend.put_locale(&quot;en&quot;) {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-US&quot;, cldr_locale_name: &quot;en&quot;, language_subtags: [], extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en&quot;, script: &quot;Latn&quot;, territory: &quot;US&quot;, transform: %{}, language_variant: nil }} iex&gt; Cldr.Print.Backend.put_locale(&quot;invalid-locale&quot;) {:error, {Cldr.LanguageTag.ParseError, &quot;Expected a BCP47 language tag. Could not parse the remaining \\&quot;le\\&quot; starting at position 13&quot;}}"},{"ref":"Cldr.Print.Backend.html#quote/2","title":"Cldr.Print.Backend.quote/2","type":"function","doc":"Add locale-specific quotation marks around a string. Arguments string is any valid Elixir string options is a keyword list of options Options locale is any valid locale name returned by Cldr.known_locale_names/1. The default is Cldr.get_locale/0 Examples iex&gt; Cldr.Print.Backend.quote &quot;Quoted String&quot; &quot;“Quoted String”&quot; iex&gt; Cldr.Print.Backend.quote &quot;Quoted String&quot;, locale: &quot;ja&quot; &quot;「Quoted String」&quot;"},{"ref":"Cldr.Print.Backend.html#unknown_locale_names/0","title":"Cldr.Print.Backend.unknown_locale_names/0","type":"function","doc":"Returns a list of the locales names that are configured, but not known in CLDR. Since there is a compile-time exception raised if there are any unknown locales this function should always return an empty list."},{"ref":"Cldr.Print.Backend.html#validate_calendar/1","title":"Cldr.Print.Backend.validate_calendar/1","type":"function","doc":"See Cldr.validate_calendar/1."},{"ref":"Cldr.Print.Backend.html#validate_currency/1","title":"Cldr.Print.Backend.validate_currency/1","type":"function","doc":"See Cldr.validate_currency/1."},{"ref":"Cldr.Print.Backend.html#validate_locale/1","title":"Cldr.Print.Backend.validate_locale/1","type":"function","doc":"Normalise and validate a locale name. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/1 Returns {:ok, language_tag} {:error, reason} Notes See rfc5646 for the specification of a language tag and consult Cldr.Rfc5646.Parser for the specification as implemented that includes the CLDR extensions for &quot;u&quot; (locales) and &quot;t&quot; (transforms). Examples iex&gt; Cldr.Print.Backend.validate_locale(&quot;en&quot;) {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-US&quot;, cldr_locale_name: &quot;en&quot;, extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en&quot;, script: &quot;Latn&quot;, territory: &quot;US&quot;, transform: %{}, language_variant: nil }} iex&gt; Cldr.Print.Backend.validate_locale Cldr.Print.Backend.default_locale() {:ok, %Cldr.LanguageTag{ canonical_locale_name: &quot;en-Latn-001&quot;, cldr_locale_name: &quot;en-001&quot;, extensions: %{}, gettext_locale_name: &quot;en&quot;, language: &quot;en&quot;, locale: %{}, private_use: [], rbnf_locale_name: &quot;en&quot;, requested_locale_name: &quot;en-001&quot;, script: &quot;Latn&quot;, territory: &quot;001&quot;, transform: %{}, language_variant: nil }} iex&gt; Cldr.Print.Backend.validate_locale(&quot;zzz&quot;) {:error, {Cldr.UnknownLocaleError, &quot;The locale \\&quot;zzz\\&quot; is not known.&quot;}}"},{"ref":"Cldr.Print.Backend.html#validate_number_system/1","title":"Cldr.Print.Backend.validate_number_system/1","type":"function","doc":"See Cldr.validate_number_system/1."},{"ref":"Cldr.Print.Backend.html#validate_number_system_type/1","title":"Cldr.Print.Backend.validate_number_system_type/1","type":"function","doc":"Normalise and validate a number system type. Arguments number_system_type is any number system type returned by Cldr.known_number_system_types/1 Returns {:ok, normalized_number_system_type} or {:error, {exception, message}} Examples iex&gt; Cldr.Print.Backend.validate_number_system_type :default {:ok, :default} iex&gt; Cldr.Print.Backend.validate_number_system_type :traditional {:ok, :traditional} iex&gt; Cldr.Print.Backend.validate_number_system_type :latn { :error, {Cldr.UnknownNumberSystemTypeError, &quot;The number system type :latn is unknown&quot;} } iex&gt; Cldr.Print.Backend.validate_number_system_type &quot;bork&quot; { :error, {Cldr.UnknownNumberSystemTypeError, &quot;The number system type \\&quot;bork\\&quot; is invalid&quot;} }"},{"ref":"Cldr.Print.Backend.html#validate_territory/1","title":"Cldr.Print.Backend.validate_territory/1","type":"function","doc":"See Cldr.validate_territory/1."},{"ref":"Cldr.Print.Backend.Currency.html","title":"Cldr.Print.Backend.Currency","type":"module","doc":""},{"ref":"Cldr.Print.Backend.Currency.html#currencies_for_locale/2","title":"Cldr.Print.Backend.Currency.currencies_for_locale/2","type":"function","doc":"Returns a map of the metadata for all currencies for a given locale. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by MyApp.Cldr.Locale.new!/1 currency_status is :all, :current, :historic, unannotated or :tender; or a list of one or more status. The default is :all. See Cldr.Currency.currency_filter/2. Returns {:ok, currency_map} or {:error, {exception, reason}} Example MyApp.Cldr.Currency.currencies_for_locale &quot;en&quot; =&gt; {:ok, %{ FJD: %Cldr.Currency{ cash_digits: 2, cash_rounding: 0, code: &quot;FJD&quot;, count: %{one: &quot;Fijian dollar&quot;, other: &quot;Fijian dollars&quot;}, digits: 2, from: nil, iso_digits: 2, name: &quot;Fijian Dollar&quot;, narrow_symbol: &quot;$&quot;, rounding: 0, symbol: &quot;FJD&quot;, tender: true, to: nil }, SUR: %Cldr.Currency{ cash_digits: 2, cash_rounding: 0, code: &quot;SUR&quot;, count: %{one: &quot;Soviet rouble&quot;, other: &quot;Soviet roubles&quot;}, digits: 2, from: nil, iso_digits: nil, name: &quot;Soviet Rouble&quot;, narrow_symbol: nil, rounding: 0, symbol: &quot;SUR&quot;, tender: true, to: nil }, ... }}"},{"ref":"Cldr.Print.Backend.Currency.html#currencies_for_locale!/2","title":"Cldr.Print.Backend.Currency.currencies_for_locale!/2","type":"function","doc":"Returns a map of the metadata for all currencies for a given locale and raises on error. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by MyApp.Cldr.Locale.new!/1 currency_status is :all, :current, :historic, unannotated or :tender; or a list of one or more status. The default is :all. See Cldr.Currency.currency_filter/2. Returns {:ok, currency_map} or raises an exception Example MyApp.Cldr.Currency.currencies_for_locale! &quot;en&quot; =&gt; %{ FJD: %Cldr.Currency{ cash_digits: 2, cash_rounding: 0, code: &quot;FJD&quot;, count: %{one: &quot;Fijian dollar&quot;, other: &quot;Fijian dollars&quot;}, digits: 2, from: nil, iso_digits: 2, name: &quot;Fijian Dollar&quot;, narrow_symbol: &quot;$&quot;, rounding: 0, symbol: &quot;FJD&quot;, tender: true, to: nil }, SUR: %Cldr.Currency{ cash_digits: 2, cash_rounding: 0, code: &quot;SUR&quot;, count: %{one: &quot;Soviet rouble&quot;, other: &quot;Soviet roubles&quot;}, digits: 2, from: nil, iso_digits: nil, name: &quot;Soviet Rouble&quot;, narrow_symbol: nil, rounding: 0, symbol: &quot;SUR&quot;, tender: true, to: nil }, ... }"},{"ref":"Cldr.Print.Backend.Currency.html#currency_for_code/2","title":"Cldr.Print.Backend.Currency.currency_for_code/2","type":"function","doc":"Returns the currency metadata for the requested currency code. Arguments currency_code is a binary or atom representation of an ISO 4217 currency code. Examples iex&gt; Cldr.Print.Backend.Currency.currency_for_code(&quot;AUD&quot;) {:ok, %Cldr.Currency{ cash_digits: 2, cash_rounding: 0, code: &quot;AUD&quot;, count: %{one: &quot;Australian dollar&quot;, other: &quot;Australian dollars&quot;}, digits: 2, iso_digits: 2, name: &quot;Australian Dollar&quot;, narrow_symbol: &quot;$&quot;, rounding: 0, symbol: &quot;A$&quot;, tender: true }} iex&gt; Cldr.Print.Backend.Currency.currency_for_code(&quot;THB&quot;) {:ok, %Cldr.Currency{ cash_digits: 2, cash_rounding: 0, code: &quot;THB&quot;, count: %{one: &quot;Thai baht&quot;, other: &quot;Thai baht&quot;}, digits: 2, iso_digits: 2, name: &quot;Thai Baht&quot;, narrow_symbol: &quot;฿&quot;, rounding: 0, symbol: &quot;THB&quot;, tender: true }}"},{"ref":"Cldr.Print.Backend.Currency.html#currency_history_for_locale/1","title":"Cldr.Print.Backend.Currency.currency_history_for_locale/1","type":"function","doc":"Returns a list of historic and the current currency for a given locale. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by MyApp.Cldr.Locale.new!/1 Example iex&gt; MyApp.Cldr.Currency.currency_history_for_locale &quot;en&quot; %{ USD: %{from: ~D[1792-01-01], to: nil}, USN: %{tender: false}, USS: %{from: nil, tender: false, to: ~D[2014-03-01]} }"},{"ref":"Cldr.Print.Backend.Currency.html#currency_strings/2","title":"Cldr.Print.Backend.Currency.currency_strings/2","type":"function","doc":"Returns a map that matches a currency string to a currency code. A currency string is a localised name or symbol representing a currency in a locale-specific manner. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by MyApp.Cldr.Locale.new!/1 currency_status is :all, :current, :historic, unannotated or :tender; or a list of one or more status. The default is :all. See Cldr.Currency.currency_filter/2. Returns {:ok, currency_string_map} or {:error, {exception, reason}} Example MyApp.Cldr.Currency.currency_strings &quot;en&quot; =&gt; {:ok, %{ &quot;mexican silver pesos&quot; =&gt; :MXP, &quot;sudanese dinar&quot; =&gt; :SDD, &quot;bad&quot; =&gt; :BAD, &quot;rsd&quot; =&gt; :RSD, &quot;swazi lilangeni&quot; =&gt; :SZL, &quot;zairean new zaire&quot; =&gt; :ZRN, &quot;guyanaese dollars&quot; =&gt; :GYD, &quot;equatorial guinean ekwele&quot; =&gt; :GQE, ... }}"},{"ref":"Cldr.Print.Backend.Currency.html#currency_strings!/2","title":"Cldr.Print.Backend.Currency.currency_strings!/2","type":"function","doc":"Returns a map that matches a currency string to a currency code or raises an exception. A currency string is a localised name or symbol representing a currency in a locale-specific manner. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by MyApp.Cldr.Locale.new!/1 currency_status is :all, :current, :historic, unannotated or :tender; or a list of one or more status. The default is :all. See Cldr.Currency.currency_filter/2. Returns {:ok, currency_string_map} or raises an exception Example MyApp.Cldr.Currency.currency_strings! &quot;en&quot; =&gt; %{ &quot;mexican silver pesos&quot; =&gt; :MXP, &quot;sudanese dinar&quot; =&gt; :SDD, &quot;bad&quot; =&gt; :BAD, &quot;rsd&quot; =&gt; :RSD, &quot;swazi lilangeni&quot; =&gt; :SZL, &quot;zairean new zaire&quot; =&gt; :ZRN, &quot;guyanaese dollars&quot; =&gt; :GYD, &quot;equatorial guinean ekwele&quot; =&gt; :GQE, ... }"},{"ref":"Cldr.Print.Backend.Currency.html#current_currency_for_locale/1","title":"Cldr.Print.Backend.Currency.current_currency_for_locale/1","type":"function","doc":"Returns the current currency for a given locale. Arguments locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by MyApp.Cldr.Locale.new!/1 Example iex&gt; MyApp.Cldr.Currency.current_currency_for_locale &quot;en&quot; :USD iex&gt; MyApp.Cldr.Currency.current_currency_for_locale &quot;en-AU&quot; :AUD"},{"ref":"Cldr.Print.Backend.Currency.html#known_currencies/0","title":"Cldr.Print.Backend.Currency.known_currencies/0","type":"function","doc":"Returns a list of all known currency codes. Example iex&gt; Cldr.Print.Backend.Currency.known_currencies |&gt; Enum.count 303"},{"ref":"Cldr.Print.Backend.Currency.html#known_currency?/2","title":"Cldr.Print.Backend.Currency.known_currency?/2","type":"function","doc":"Returns a boolean indicating if the supplied currency code is known. Arguments currency_code is a binary or atom representing an ISO4217 currency code custom_currencies is an optional list of custom currencies created by the Cldr.Currency.new/2 function Returns true or false Examples iex&gt; Cldr.Print.Backend.Currency.known_currency? &quot;AUD&quot; true iex&gt; Cldr.Print.Backend.Currency.known_currency? &quot;GGG&quot; false iex&gt; Cldr.Print.Backend.Currency.known_currency? :XCV false iex&gt; Cldr.Print.Backend.Currency.known_currency? :XCV, [%Cldr.Currency{code: :XCV}] true"},{"ref":"Cldr.Print.Backend.Currency.html#make_currency_code/1","title":"Cldr.Print.Backend.Currency.make_currency_code/1","type":"function","doc":"Returns a valid normalized ISO4217 format custom currency code or an error. Currency codes conform to the ISO4217 standard which means that any custom currency code must start with an &quot;X&quot; followed by two alphabetic characters. Note that since this function creates atoms but to a maximum of 26 * 26 == 676 since the format permits 2 alphabetic characters only. Arguments currency_code is a String.t or and atom representing the new currency code to be created Returns {:ok, currency_code} or {:error, {exception, message}} Examples iex&gt; Cldr.Print.Backend.Currency.make_currency_code(&quot;xzz&quot;) {:ok, :XZZ} iex&gt; Cldr.Print.Backend.Currency.make_currency_code(&quot;aaa&quot;) {:error, {Cldr.CurrencyCodeInvalid, &quot;Invalid currency code \\&quot;AAA\\&quot;. Currency codes must start with &#39;X&#39; followed by 2 alphabetic characters only.&quot;}}"},{"ref":"Cldr.Print.Backend.Currency.html#new/2","title":"Cldr.Print.Backend.Currency.new/2","type":"function","doc":"Returns a Currency struct created from the arguments. Arguments currency is a custom currency code of a format defined in ISO4217 options is a map of options representing the optional elements of the %Cldr.Currency{} struct Returns {:ok, Cldr.Currency.t} or {:error, {exception, message}} Example iex&gt; Cldr.Print.Backend.Currency.new(:XAA) {:ok, %Cldr.Currency{cash_digits: 0, cash_rounding: 0, code: :XAA, count: nil, digits: 0, name: &quot;&quot;, narrow_symbol: nil, rounding: 0, symbol: &quot;&quot;, tender: false}} iex&gt; Cldr.Print.Backend.Currency.new(:ZAA, name: &quot;Invalid Custom Name&quot;) {:error, {Cldr.UnknownCurrencyError, &quot;The currency :ZAA is invalid&quot;}} iex&gt; Cldr.Print.Backend.Currency.new(&quot;xaa&quot;, name: &quot;Custom Name&quot;) {:ok, %Cldr.Currency{cash_digits: 0, cash_rounding: 0, code: :XAA, count: nil, digits: 0, name: &quot;Custom Name&quot;, narrow_symbol: nil, rounding: 0, symbol: &quot;&quot;, tender: false}} iex&gt; Cldr.Print.Backend.Currency.new(:XAA, name: &quot;Custom Name&quot;) {:ok, %Cldr.Currency{cash_digits: 0, cash_rounding: 0, code: :XAA, count: nil, digits: 0, name: &quot;Custom Name&quot;, narrow_symbol: nil, rounding: 0, symbol: &quot;&quot;, tender: false}} iex&gt; Cldr.Print.Backend.Currency.new(:XBC) {:error, {Cldr.CurrencyAlreadyDefined, &quot;Currency :XBC is already defined&quot;}}"},{"ref":"Cldr.Print.Backend.Currency.html#pluralize/3","title":"Cldr.Print.Backend.Currency.pluralize/3","type":"function","doc":"Returns the appropriate currency display name for the currency, based on the plural rules in effect for the locale. Arguments number is an integer, float or Decimal currency is any currency returned by Cldr.Currency.known_currencies/0 options is a keyword list of options Options locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by MyApp.Cldr.Locale.new!/1. The default is Cldr.get_current_locale/1 Returns {:ok, plural_string} or {:error, {exception, message}} Examples iex&gt; Cldr.Print.Backend.Currency.pluralize 1, :USD {:ok, &quot;US dollar&quot;} iex&gt; Cldr.Print.Backend.Currency.pluralize 3, :USD {:ok, &quot;US dollars&quot;} iex&gt; Cldr.Print.Backend.Currency.pluralize 12, :USD, locale: &quot;zh&quot; {:ok, &quot;美元&quot;} iex&gt; Cldr.Print.Backend.Currency.pluralize 12, :USD, locale: &quot;fr&quot; {:ok, &quot;dollars des États-Unis&quot;} iex&gt; Cldr.Print.Backend.Currency.pluralize 1, :USD, locale: &quot;fr&quot; {:ok, &quot;dollar des États-Unis&quot;}"},{"ref":"Cldr.Print.Backend.Currency.html#strings_for_currency/2","title":"Cldr.Print.Backend.Currency.strings_for_currency/2","type":"function","doc":"Returns the strings associated with a currency in a given locale. Arguments currency is an ISO4217 currency code locale is any valid locale name returned by MyApp.Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by MyApp.Cldr.Locale.new!/1 Returns A list of strings or {:error, {exception, reason}} Example iex&gt; MyApp.Cldr.Currency.strings_for_currency :AUD, &quot;en&quot; [&quot;a$&quot;, &quot;australian dollars&quot;, &quot;aud&quot;, &quot;australian dollar&quot;]"},{"ref":"Cldr.Print.Backend.Locale.html","title":"Cldr.Print.Backend.Locale","type":"module","doc":"Backend module that provides functions to define new locales."},{"ref":"Cldr.Print.Backend.Locale.html#new/1","title":"Cldr.Print.Backend.Locale.new/1","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Locale.html#new!/1","title":"Cldr.Print.Backend.Locale.new!/1","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Number.html","title":"Cldr.Print.Backend.Number","type":"module","doc":"Formats numbers and currencies based upon CLDR&#39;s decimal formats specification. The format specification is documentated in Unicode TR35. There are several classes of formatting including non-scientific, scientific, rules based (for spelling and ordinal formats), compact formats that display 1k rather than 1,000 and so on. See Cldr.Number.to_string/2 for specific formatting options. Non-Scientific Notation Formatting The following description applies to formats that do not use scientific notation or significant digits: If the number of actual integer digits exceeds the maximum integer digits, then only the least significant digits are shown. For example, 1997 is formatted as &quot;97&quot; if the maximum integer digits is set to 2. If the number of actual integer digits is less than the minimum integer digits, then leading zeros are added. For example, 1997 is formatted as &quot;01997&quot; if the minimum integer digits is set to 5. If the number of actual fraction digits exceeds the maximum fraction digits, then half-even rounding it performed to the maximum fraction digits. For example, 0.125 is formatted as &quot;0.12&quot; if the maximum fraction digits is 2. This behavior can be changed by specifying a rounding increment and a rounding mode. If the number of actual fraction digits is less than the minimum fraction digits, then trailing zeros are added. For example, 0.125 is formatted as &quot;0.1250&quot; if the minimum fraction digits is set to 4. Trailing fractional zeros are not displayed if they occur j positions after the decimal, where j is less than the maximum fraction digits. For example, 0.10004 is formatted as &quot;0.1&quot; if the maximum fraction digits is four or less. Scientific Notation Formatting Numbers in scientific notation are expressed as the product of a mantissa and a power of ten, for example, 1234 can be expressed as 1.234 x 10^3. The mantissa is typically in the half-open interval [1.0, 10.0) or sometimes [0.0, 1.0), but it need not be. In a pattern, the exponent character immediately followed by one or more digit characters indicates scientific notation. Example: &quot;0.###E0&quot; formats the number 1234 as &quot;1.234E3&quot;. The number of digit characters after the exponent character gives the minimum exponent digit count. There is no maximum. Negative exponents are formatted using the localized minus sign, not the prefix and suffix from the pattern. This allows patterns such as &quot;0.###E0 m/s&quot;. To prefix positive exponents with a localized plus sign, specify &#39;+&#39; between the exponent and the digits: &quot;0.###E+0&quot; will produce formats &quot;1E+1&quot;, &quot;1E+0&quot;, &quot;1E-1&quot;, and so on. (In localized patterns, use the localized plus sign rather than &#39;+&#39;.) The minimum number of integer digits is achieved by adjusting the exponent. Example: 0.00123 formatted with &quot;00.###E0&quot; yields &quot;12.3E-4&quot;. This only happens if there is no maximum number of integer digits. If there is a maximum, then the minimum number of integer digits is fixed at one. The maximum number of integer digits, if present, specifies the exponent grouping. The most common use of this is to generate engineering notation, in which the exponent is a multiple of three, for example, &quot;##0.###E0&quot;. The number 12345 is formatted using &quot;##0.####E0&quot; as &quot;12.345E3&quot;. When using scientific notation, the formatter controls the digit counts using significant digits logic. The maximum number of significant digits limits the total number of integer and fraction digits that will be shown in the mantissa; it does not affect parsing. For example, 12345 formatted with &quot;##0.##E0&quot; is &quot;12.3E3&quot;. Exponential patterns may not contain grouping separators. Significant Digits There are two ways of controlling how many digits are shows: (a) significant digits counts, or (b) integer and fraction digit counts. Integer and fraction digit counts are described above. When a formatter is using significant digits counts, it uses however many integer and fraction digits are required to display the specified number of significant digits. It may ignore min/max integer/fraction digits, or it may use them to the extent possible."},{"ref":"Cldr.Print.Backend.Number.html#to_approx_string/2","title":"Cldr.Print.Backend.Number.to_approx_string/2","type":"function","doc":"Formats a number and applies the :approximately format for a locale and number system. Arguments number is an integer, float or Decimal to be formatted options is a keyword list defining how the number is to be formatted. See Cldr.Number.to_string/3 for a description of the available options. Example iex&gt; Cldr.Print.Backend.Number.to_approx_string 1234 {:ok, &quot;~1,234&quot;}"},{"ref":"Cldr.Print.Backend.Number.html#to_at_least_string/2","title":"Cldr.Print.Backend.Number.to_at_least_string/2","type":"function","doc":"Formats a number and applies the :at_least format for a locale and number system. Arguments number is an integer, float or Decimal to be formatted options is a keyword list defining how the number is to be formatted. See Cldr.Print.Backend.Number.to_string/2 for a description of the available options. Example iex&gt; Cldr.Print.Backend.Number.to_at_least_string 1234 {:ok, &quot;1,234+&quot;}"},{"ref":"Cldr.Print.Backend.Number.html#to_at_most_string/2","title":"Cldr.Print.Backend.Number.to_at_most_string/2","type":"function","doc":"Formats a number and applies the :at_most format for a locale and number system. Arguments number is an integer, float or Decimal to be formatted options is a keyword list defining how the number is to be formatted. See Cldr.Number.to_string/3 for a description of the available options. Example iex&gt; Cldr.Print.Backend.Number.to_at_most_string 1234 {:ok, &quot;≤1,234&quot;}"},{"ref":"Cldr.Print.Backend.Number.html#to_range_string/2","title":"Cldr.Print.Backend.Number.to_range_string/2","type":"function","doc":"Formats the first and last numbers of a range and applies the :range format for a locale and number system. Arguments number is an integer, float or Decimal to be formatted options is a keyword list defining how the number is to be formatted. See Cldr.Number.to_string/3 for a description of the available options. Example iex&gt; Cldr.Print.Backend.Number.to_range_string 1234..5678 {:ok, &quot;1,234–5,678&quot;}"},{"ref":"Cldr.Print.Backend.Number.html#to_string/2","title":"Cldr.Print.Backend.Number.to_string/2","type":"function","doc":"Returns a number formatted into a string according to a format pattern and options. Arguments number is an integer, float or Decimal to be formatted options is a keyword list defining how the number is to be formatted. Options format: the format style or a format string defining how the number is formatted. See Cldr.Number.Format for how format strings can be constructed. See Cldr.Number.Format.format_styles_for/3 to return available format styles for a locale. The default format is :standard. If :format is set to :long or :short then the formatting depends on whether :currency is specified. If not specified then the number is formatted as :decimal_long or :decimal_short. If :currency is specified the number is formatted as :currency_long or :currency_short and :fractional_digits is set to 0 as a default. :format may also be a format defined by CLDR&#39;s Rules Based Number Formats (RBNF). Further information is found in the module Cldr.Rbnf. The most commonly used formats in this category are to spell out the number in a the locales language. The applicable formats are :spellout, :spellout_year, :ordinal. A number can also be formatted as roman numbers by using the format :roman or :roman_lower. currency: is the currency for which the number is formatted. For available currencies see Cldr.Currency.known_currencies/0. This option is required if :format is set to :currency. If currency is set and no :format is set, :format will be set to :currency as well. :cash: a boolean which indicates whether a number being formatted as a :currency is to be considered a cash value or not. Currencies can be rounded differently depending on whether :cash is true or false. *This option is deprecated in favour of currency_digits: :cash. :currency_digits indicates which of the rounding and digits should be used. The options are :accounting which is the default, :cash or :iso :rounding_mode: determines how a number is rounded to meet the precision of the format requested. The available rounding modes are :down, :half_up, :half_even, :ceiling, :floor, :half_down, :up. The default is :half_even. :number_system: determines which of the number systems for a locale should be used to define the separators and digits for the formatted number. If number_system is an atom then number_system is interpreted as a number system. If the :number_system is binary then it is interpreted as a number system name. See Cldr.Number.System.number_system_names_for/2. The default is :default. :locale: determines the locale in which the number is formatted. See Cldr.known_locale_names/0. The default isCldr.get_locale/0 which is the locale currently in affect for this Process and which is set by Cldr.put_locale/1. :fractional_digits is set to a positive integer value then the number will be rounded to that number of digits and displayed accordingly overriding settings that would be applied by default. For example, currencies have fractional digits defined reflecting each currencies minor unit. Setting :fractional_digits will override that setting. :minimum_grouping_digits overrides the CLDR definition of minimum grouping digits. For example in the locale es the number 1234 is formatted by default as 1345 because the locale defines the minimium_grouping_digits as 2. If minimum_grouping_digits: 1 is set as an option the number is formatting as 1.345. The :minimum_grouping_digits is added to the grouping defined by the number format. If the sum of these two digits is greater than the number of digits in the integer (or fractional) part of the number then no grouping is performed. Returns {:ok, string} or {:error, {exception, message}} Examples iex&gt; Cldr.Print.Backend.Number.to_string 12345 {:ok, &quot;12,345&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 12345, locale: &quot;fr&quot; {:ok, &quot;12 345&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 1345.32, currency: :EUR, locale: &quot;es&quot;, minimum_grouping_digits: 1 {:ok, &quot;1.345,32 €&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 1345.32, currency: :EUR, locale: &quot;es&quot; {:ok, &quot;1345,32 €&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 12345, locale: &quot;fr&quot;, currency: &quot;USD&quot; {:ok, &quot;12 345,00 $US&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 12345, format: &quot;#E0&quot; {:ok, &quot;1.2345E4&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 12345, format: :accounting, currency: &quot;THB&quot; {:ok, &quot;THB 12,345.00&quot;} iex&gt; Cldr.Print.Backend.Number.to_string -12345, format: :accounting, currency: &quot;THB&quot; {:ok, &quot;(THB 12,345.00)&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 12345, format: :accounting, currency: &quot;THB&quot;, ...&gt; locale: &quot;th&quot; {:ok, &quot;฿12,345.00&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 12345, format: :accounting, currency: &quot;THB&quot;, ...&gt; locale: &quot;th&quot;, number_system: :native {:ok, &quot;฿๑๒,๓๔๕.๐๐&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 1244.30, format: :long {:ok, &quot;1 thousand&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 1244.30, format: :long, currency: &quot;USD&quot; {:ok, &quot;1,244 US dollars&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 1244.30, format: :short {:ok, &quot;1K&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 1244.30, format: :short, currency: &quot;EUR&quot; {:ok, &quot;€1K&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 1234, format: :spellout {:ok, &quot;one thousand two hundred thirty-four&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 1234, format: :spellout_verbose {:ok, &quot;one thousand two hundred and thirty-four&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 1989, format: :spellout_year {:ok, &quot;nineteen eighty-nine&quot;} iex&gt; Cldr.Print.Backend.Number.to_string 123, format: :ordinal {:ok, &quot;123rd&quot;} iex(4)&gt; Cldr.Print.Backend.Number.to_string 123, format: :roman {:ok, &quot;CXXIII&quot;} Errors An error tuple {:error, reason} will be returned if an error is detected. The two most likely causes of an error return are: A format cannot be compiled. In this case the error tuple will look like: iex&gt; Cldr.Print.Backend.Number.to_string(12345, format: &quot;0#&quot;) {:error, {Cldr.FormatCompileError, &quot;Decimal format compiler: syntax error before: \\&quot;#\\&quot;&quot;}} A currency was not specific for a format type of format: :currency or format: :accounting or any other format that specifies a currency symbol placeholder. In this case the error return looks like: iex&gt; Cldr.Print.Backend.Number.to_string(12345, format: :accounting) {:error, {Cldr.FormatError, &quot;currency format \\&quot;¤#,##0.00;(¤#,##0.00)\\&quot; requires that &quot; &lt;&gt; &quot;options[:currency] be specified&quot;}} The format style requested is not defined for the locale and number_system. This happens typically when the number system is :algorithmic rather than the more common :numeric. In this case the error return looks like: iex&gt; Cldr.Print.Backend.Number.to_string(1234, locale: &quot;he&quot;, number_system: &quot;hebr&quot;) {:error, {Cldr.UnknownFormatError, &quot;The locale \\&quot;he\\&quot; with number system :hebr does not define a format :standard.&quot;}}"},{"ref":"Cldr.Print.Backend.Number.html#to_string!/2","title":"Cldr.Print.Backend.Number.to_string!/2","type":"function","doc":"Same as the execution of to_string/2 but raises an exception if an error would be returned. Arguments number is an integer, float or Decimal to be formatted options is a keyword list defining how the number is to be formatted. See Cldr.Print.Backend.Number.to_string/2 Returns a formatted number as a string or raises an exception Examples iex&gt; Cldr.Print.Backend.Number.to_string! 12345 &quot;12,345&quot; iex&gt; Cldr.Print.Backend.Number.to_string! 12345, locale: &quot;fr&quot; &quot;12 345&quot;"},{"ref":"Cldr.Print.Backend.Number.html#validate_number_system/2","title":"Cldr.Print.Backend.Number.validate_number_system/2","type":"function","doc":"Return a valid number system from a provided locale and number system name or type. The number system or number system type must be valid for the given locale. If a number system type is provided, the underlying number system is returned. Arguments locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/2 system_name is any number system name returned by Cldr.known_number_systems/0 or a number system type returned by Cldr.known_number_system_types/0 Examples iex&gt; Cldr.Print.Backend.Number.validate_number_system &quot;en&quot;, :latn {:ok, :latn} iex&gt; Cldr.Print.Backend.Number.validate_number_system &quot;en&quot;, :default {:ok, :latn} iex&gt; Cldr.Print.Backend.Number.validate_number_system &quot;en&quot;, :unknown {:error, {Cldr.UnknownNumberSystemError, &quot;The number system :unknown is unknown&quot;}} iex&gt; Cldr.Print.Backend.Number.validate_number_system &quot;zz&quot;, :default {:error, {Cldr.UnknownLocaleError, &quot;The locale \\&quot;zz\\&quot; is not known.&quot;}}"},{"ref":"Cldr.Print.Backend.Number.Cardinal.html","title":"Cldr.Print.Backend.Number.Cardinal","type":"module","doc":"Implements cardinal plural rules for numbers."},{"ref":"Cldr.Print.Backend.Number.Cardinal.html#available_locale_names/0","title":"Cldr.Print.Backend.Number.Cardinal.available_locale_names/0","type":"function","doc":"The locale names for which plural rules are defined."},{"ref":"Cldr.Print.Backend.Number.Cardinal.html#known_locale_names/0","title":"Cldr.Print.Backend.Number.Cardinal.known_locale_names/0","type":"function","doc":"The configured locales for which plural rules are defined. Returns the intersection of Cldr.Print.Backend.known_locale_names/0 and the locales for which Cardinal plural rules are defined. There are many Cldr locales which don&#39;t have their own plural rules so this list is the intersection of Cldr&#39;s configured locales and those that have rules."},{"ref":"Cldr.Print.Backend.Number.Cardinal.html#plural_rule/3","title":"Cldr.Print.Backend.Number.Cardinal.plural_rule/3","type":"function","doc":"Return the plural key for a given number in a given locale Returns which plural key (:zero, :one, :two, :few, :many or :other) a given number fits into within the context of a given locale. Note that these key names should not be interpreted literally. For example, the key returned from Cldr.Number.Ordinal.plural_rule(0, &quot;en&quot;) is actually :other, not :zero. This key can then be used to format a number, date, time, unit, list or other content in a plural-sensitive way. Arguments number is any integer, float or Decimal locale is any locale returned by Cldr.Locale.new!/2 or any locale_name returned by Cldr.Print.Backend.known_locale_names/0 rounding is one of [:down, :up, :ceiling, :floor, :half_even, :half_up, :half_down]. The default is :half_even. Examples iex&gt; Cldr.Print.Backend.Number.Cardinal.plural_rule 0, &quot;fr&quot; :one iex&gt; Cldr.Print.Backend.Number.Cardinal.plural_rule 0, &quot;en&quot; :other"},{"ref":"Cldr.Print.Backend.Number.Cardinal.html#plural_rules/0","title":"Cldr.Print.Backend.Number.Cardinal.plural_rules/0","type":"function","doc":"Returns all the plural rules defined in CLDR."},{"ref":"Cldr.Print.Backend.Number.Cardinal.html#plural_rules_for/1","title":"Cldr.Print.Backend.Number.Cardinal.plural_rules_for/1","type":"function","doc":"Return the plural rules for a locale. Arguments locale is any locale returned by Cldr.Print.Backend.Locale.new!/1 or any locale_name returned by Cldr.Print.Backend.known_locale_names/0 The rules are returned in AST form after parsing."},{"ref":"Cldr.Print.Backend.Number.Cardinal.html#pluralize/3","title":"Cldr.Print.Backend.Number.Cardinal.pluralize/3","type":"function","doc":"Pluralize a number using cardinal plural rules and a substition map. Arguments number is an integer, float or Decimal locale is any locale returned by Cldr.Print.Backend.Locale.new!/1 or any locale_name returned by Cldr.Print.Backend.known_locale_names/0 substitutions is a map that maps plural keys to a string. The valid substitution keys are :zero, :one, :two, :few, :many and :other. See also Cldr.Print.Backend.Number.Cardinal.Cardinal.plural_rule/3. Examples iex&gt; Cldr.Print.Backend.Number.Cardinal.pluralize 1, &quot;en&quot;, %{one: &quot;one&quot;} &quot;one&quot; iex&gt; Cldr.Print.Backend.Number.Cardinal.pluralize 2, &quot;en&quot;, %{one: &quot;one&quot;} nil iex&gt; Cldr.Print.Backend.Number.Cardinal.pluralize 2, &quot;en&quot;, %{one: &quot;one&quot;, two: &quot;two&quot;, other: &quot;other&quot;} &quot;other&quot; iex&gt; Cldr.Print.Backend.Number.Cardinal.pluralize 22, &quot;en&quot;, %{one: &quot;one&quot;, two: &quot;two&quot;, other: &quot;other&quot;} &quot;other&quot; iex&gt; Cldr.Print.Backend.Number.Cardinal.pluralize Decimal.new(1), &quot;en&quot;, %{one: &quot;one&quot;} &quot;one&quot; iex&gt; Cldr.Print.Backend.Number.Cardinal.pluralize Decimal.new(2), &quot;en&quot;, %{one: &quot;one&quot;} nil iex&gt; Cldr.Print.Backend.Number.Cardinal.pluralize Decimal.new(2), &quot;en&quot;, %{one: &quot;one&quot;, two: &quot;two&quot;} nil iex&gt; Cldr.Print.Backend.Number.Cardinal.pluralize 1..10, &quot;ar&quot;, %{one: &quot;one&quot;, few: &quot;few&quot;, other: &quot;other&quot;} &quot;few&quot; iex&gt; Cldr.Print.Backend.Number.Cardinal.pluralize 1..10, &quot;en&quot;, %{one: &quot;one&quot;, few: &quot;few&quot;, other: &quot;other&quot;} &quot;other&quot;"},{"ref":"Cldr.Print.Backend.Number.Format.html","title":"Cldr.Print.Backend.Number.Format","type":"module","doc":"Functions to manage the collection of number patterns defined in Cldr. Number patterns affect how numbers are interpreted in a localized context. Here are some examples, based on the French locale. The &quot;.&quot; shows where the decimal point should go. The &quot;,&quot; shows where the thousands separator should go. A &quot;0&quot; indicates zero-padding: if the number is too short, a zero (in the locale&#39;s numeric set) will go there. A &quot;#&quot; indicates no padding: if the number is too short, nothing goes there. A &quot;¤&quot; shows where the currency sign will go. The following illustrates the effects of different patterns for the French locale, with the number &quot;1234.567&quot;. Notice how the pattern characters &#39;,&#39; and &#39;.&#39; are replaced by the characters appropriate for the locale. Number Pattern Examples PatternCurrencyText #,##0.##n/a1 234,57 #,##0.###n/a1 234,567 ###0.#####n/a1234,567 ###0.0000#n/a1234,5670 00000.0000n/a01234,5670 #,##0.00 ¤EUR1 234,57 € The number of # placeholder characters before the decimal do not matter, since no limit is placed on the maximum number of digits. There should, however, be at least one zero some place in the pattern. In currency formats, the number of digits after the decimal also do not matter, since the information in the supplemental data (see Supplemental Currency Data) is used to override the number of decimal places — and the rounding — according to the currency that is being formatted. That can be seen in the above chart, with the difference between Yen and Euro formatting. Details of the number formats are described in the Unicode documentation"},{"ref":"Cldr.Print.Backend.Number.Format.html#all_formats_for/1","title":"Cldr.Print.Backend.Number.Format.all_formats_for/1","type":"function","doc":"Returns the decimal formats defined for a given locale. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/1. The default is Cldr.Print.Backend.get_locale/0 Returns {:ok, map} where map is a map of decimal formats keyed by number system or {:error, {exception, message}}"},{"ref":"Cldr.Print.Backend.Number.Format.html#all_formats_for!/1","title":"Cldr.Print.Backend.Number.Format.all_formats_for!/1","type":"function","doc":"Returns the decimal formats defined for a given locale. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/1. The default is Cldr.Print.Backend.get_locale/0 Returns {:ok, map} where map is a map of decimal formats keyed by number system or raises an exception See Cldr.Print.Backend.Number.Format.Number.Format.all_formats_for/1 for further information."},{"ref":"Cldr.Print.Backend.Number.Format.html#currency_spacing/2","title":"Cldr.Print.Backend.Number.Format.currency_spacing/2","type":"function","doc":"Returns the currency space for a given locale and number system."},{"ref":"Cldr.Print.Backend.Number.Format.html#decimal_format_list/0","title":"Cldr.Print.Backend.Number.Format.decimal_format_list/0","type":"function","doc":"Returns the list of decimal formats in the configured locales including the list of locales configured for precompilation in config.exs. This function exists to allow the decimal formatter to precompile all the known formats at compile time. Example #=&gt; Cldr.Print.Backend.Number.Format.Format.decimal_format_list [&quot;#&quot;, &quot;#,##,##0%&quot;, &quot;#,##,##0.###&quot;, &quot;#,##,##0.00¤&quot;, &quot;#,##,##0.00¤;(#,##,##0.00¤)&quot;, &quot;#,##,##0 %&quot;, &quot;#,##0%&quot;, &quot;#,##0.###&quot;, &quot;#,##0.00 ¤&quot;, &quot;#,##0.00 ¤;(#,##0.00 ¤)&quot;, &quot;#,##0.00¤&quot;, &quot;#,##0.00¤;(#,##0.00¤)&quot;, &quot;#,##0 %&quot;, &quot;#0%&quot;, &quot;#0.######&quot;, &quot;#0.00 ¤&quot;, &quot;#E0&quot;, &quot;%#,##0&quot;, &quot;% #,##0&quot;, &quot;0&quot;, &quot;0.000000E+000&quot;, &quot;0000 M ¤&quot;, &quot;0000¤&quot;, &quot;000G ¤&quot;, &quot;000K ¤&quot;, &quot;000M ¤&quot;, &quot;000T ¤&quot;, &quot;000mM ¤&quot;, &quot;000m ¤&quot;, &quot;000 Bio&#39;.&#39; ¤&quot;, &quot;000 Bln ¤&quot;, &quot;000 Bn ¤&quot;, &quot;000 B ¤&quot;, &quot;000 E ¤&quot;, &quot;000 K ¤&quot;, &quot;000 MRD ¤&quot;, &quot;000 Md ¤&quot;, &quot;000 Mio&#39;.&#39; ¤&quot;, &quot;000 Mio ¤&quot;, &quot;000 Mld ¤&quot;, &quot;000 Mln ¤&quot;, &quot;000 Mn ¤&quot;, &quot;000 Mrd&#39;.&#39; ¤&quot;, &quot;000 Mrd ¤&quot;, &quot;000 Mr ¤&quot;, &quot;000 M ¤&quot;, &quot;000 NT ¤&quot;, &quot;000 N ¤&quot;, &quot;000 Tn ¤&quot;, &quot;000 Tr ¤&quot;, ...]"},{"ref":"Cldr.Print.Backend.Number.Format.html#decimal_format_list_for/1","title":"Cldr.Print.Backend.Number.Format.decimal_format_list_for/1","type":"function","doc":"Returns the list of decimal formats for a configured locale. Arguments locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/1. The default is Cldr.get_locale/0 This function exists to allow the decimal formatter to precompile all the known formats at compile time. Its use is not otherwise recommended. Example iex&gt; Cldr.Print.Backend.Number.Format.decimal_format_list_for(&quot;en&quot;) {:ok, [&quot;#,##0%&quot;, &quot;#,##0.###&quot;, &quot;#E0&quot;, &quot;0 billion&quot;, &quot;0 million&quot;, &quot;0 thousand&quot;, &quot;0 trillion&quot;, &quot;00 billion&quot;, &quot;00 million&quot;, &quot;00 thousand&quot;, &quot;00 trillion&quot;, &quot;000 billion&quot;, &quot;000 million&quot;, &quot;000 thousand&quot;, &quot;000 trillion&quot;, &quot;000B&quot;, &quot;000K&quot;, &quot;000M&quot;, &quot;000T&quot;, &quot;00B&quot;, &quot;00K&quot;, &quot;00M&quot;, &quot;00T&quot;, &quot;0B&quot;, &quot;0K&quot;, &quot;0M&quot;, &quot;0T&quot;, &quot;¤#,##0.00&quot;, &quot;¤#,##0.00;(¤#,##0.00)&quot;, &quot;¤000B&quot;, &quot;¤000K&quot;, &quot;¤000M&quot;, &quot;¤000T&quot;, &quot;¤00B&quot;, &quot;¤00K&quot;, &quot;¤00M&quot;, &quot;¤00T&quot;, &quot;¤0B&quot;, &quot;¤0K&quot;, &quot;¤0M&quot;, &quot;¤0T&quot;]}"},{"ref":"Cldr.Print.Backend.Number.Format.html#default_grouping_for/1","title":"Cldr.Print.Backend.Number.Format.default_grouping_for/1","type":"function","doc":"Returns the default grouping for a locale as a map. Arguments locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/1. The default is Cldr.Print.Backend.get_locale/0 Returns {:ok, grouping} or {:error, {exception, message}} Examples iex&gt; Cldr.Print.Backend.Number.Format.default_grouping_for(&quot;en&quot;) {:ok, %{fraction: %{first: 0, rest: 0}, integer: %{first: 3, rest: 3}}}"},{"ref":"Cldr.Print.Backend.Number.Format.html#default_grouping_for!/1","title":"Cldr.Print.Backend.Number.Format.default_grouping_for!/1","type":"function","doc":"Returns the default grouping for a locale or raises on error. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/1. The default is Cldr.Print.Backend.get_locale/0 Returns grouping as a map or raises an exception Examples iex&gt; Cldr.Print.Backend.Number.Format.default_grouping_for!(&quot;en&quot;) %{fraction: %{first: 0, rest: 0}, integer: %{first: 3, rest: 3}}"},{"ref":"Cldr.Print.Backend.Number.Format.html#formats_for/2","title":"Cldr.Print.Backend.Number.Format.formats_for/2","type":"function","doc":"Return the predfined formats for a given locale and number_system. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/1. The default is Cldr.Print.Backend.get_locale/0 number_system is any valid number system or number system type returned by Cldr.Print.Backend.Number.System.number_systems_for/1 Example Cldr.Print.Backend.Number.Format.formats_for &quot;fr&quot;, :native #=&gt; %Cldr.Number.Format{ accounting: &quot;#,##0.00 ¤;(#,##0.00 ¤)&quot;, currency: &quot;#,##0.00 ¤&quot;, percent: &quot;#,##0 %&quot;, scientific: &quot;#E0&quot;, standard: &quot;#,##0.###&quot; currency_short: [{&quot;1000&quot;, [one: &quot;0 k ¤&quot;, other: &quot;0 k ¤&quot;]}, {&quot;10000&quot;, [one: &quot;00 k ¤&quot;, other: &quot;00 k ¤&quot;]}, {&quot;100000&quot;, [one: &quot;000 k ¤&quot;, other: &quot;000 k ¤&quot;]}, {&quot;1000000&quot;, [one: &quot;0 M ¤&quot;, other: &quot;0 M ¤&quot;]}, {&quot;10000000&quot;, [one: &quot;00 M ¤&quot;, other: &quot;00 M ¤&quot;]}, {&quot;100000000&quot;, [one: &quot;000 M ¤&quot;, other: &quot;000 M ¤&quot;]}, {&quot;1000000000&quot;, [one: &quot;0 Md ¤&quot;, other: &quot;0 Md ¤&quot;]}, {&quot;10000000000&quot;, [one: &quot;00 Md ¤&quot;, other: &quot;00 Md ¤&quot;]}, {&quot;100000000000&quot;, [one: &quot;000 Md ¤&quot;, other: &quot;000 Md ¤&quot;]}, {&quot;1000000000000&quot;, [one: &quot;0 Bn ¤&quot;, other: &quot;0 Bn ¤&quot;]}, {&quot;10000000000000&quot;, [one: &quot;00 Bn ¤&quot;, other: &quot;00 Bn ¤&quot;]}, {&quot;100000000000000&quot;, [one: &quot;000 Bn ¤&quot;, other: &quot;000 Bn ¤&quot;]}], ... }"},{"ref":"Cldr.Print.Backend.Number.Format.html#formats_for!/2","title":"Cldr.Print.Backend.Number.Format.formats_for!/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Number.Format.html#minimum_grouping_digits_for/1","title":"Cldr.Print.Backend.Number.Format.minimum_grouping_digits_for/1","type":"function","doc":"Returns the minimum grouping digits for a locale. Arguments locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/1. The default is Cldr.Print.Backend.get_locale/0 Returns {:ok, minumum_digits} or {:error, {exception, message}} Examples iex&gt; Cldr.Print.Backend.Number.Format.minimum_grouping_digits_for(&quot;en&quot;) {:ok, 1}"},{"ref":"Cldr.Print.Backend.Number.Format.html#minimum_grouping_digits_for!/1","title":"Cldr.Print.Backend.Number.Format.minimum_grouping_digits_for!/1","type":"function","doc":"Returns the minium grouping digits for a locale or raises on error. Arguments locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/1. The default is Cldr.Print.Backend.get_locale/0 Returns minumum_digits or raises an exception Examples iex&gt; Cldr.Print.Backend.Number.Format.minimum_grouping_digits_for!(&quot;en&quot;) 1"},{"ref":"Cldr.Print.Backend.Number.Formatter.Decimal.html","title":"Cldr.Print.Backend.Number.Formatter.Decimal","type":"module","doc":""},{"ref":"Cldr.Print.Backend.Number.Formatter.Decimal.html#to_string/3","title":"Cldr.Print.Backend.Number.Formatter.Decimal.to_string/3","type":"function","doc":"Formats a number according to a decimal format string. Arguments number is an integer, float or Decimal format is a format string. See Cldr.Print.Backend.Number for further information. options is a map of options. See Cldr.Print.Backend.Number.to_string/2 for further information."},{"ref":"Cldr.Print.Backend.Number.Ordinal.html","title":"Cldr.Print.Backend.Number.Ordinal","type":"module","doc":"Implements ordinal plural rules for numbers."},{"ref":"Cldr.Print.Backend.Number.Ordinal.html#available_locale_names/0","title":"Cldr.Print.Backend.Number.Ordinal.available_locale_names/0","type":"function","doc":"The locale names for which plural rules are defined."},{"ref":"Cldr.Print.Backend.Number.Ordinal.html#known_locale_names/0","title":"Cldr.Print.Backend.Number.Ordinal.known_locale_names/0","type":"function","doc":"The configured locales for which plural rules are defined. Returns the intersection of Cldr.Print.Backend.known_locale_names/0 and the locales for which Ordinal plural rules are defined. There are many Cldr locales which don&#39;t have their own plural rules so this list is the intersection of Cldr&#39;s configured locales and those that have rules."},{"ref":"Cldr.Print.Backend.Number.Ordinal.html#plural_rule/3","title":"Cldr.Print.Backend.Number.Ordinal.plural_rule/3","type":"function","doc":"Return the plural key for a given number in a given locale Returns which plural key (:zero, :one, :two, :few, :many or :other) a given number fits into within the context of a given locale. Note that these key names should not be interpreted literally. For example, the key returned from Cldr.Number.Ordinal.plural_rule(0, &quot;en&quot;) is actually :other, not :zero. This key can then be used to format a number, date, time, unit, list or other content in a plural-sensitive way. Arguments number is any integer, float or Decimal locale is any locale returned by Cldr.Locale.new!/2 or any locale_name returned by Cldr.Print.Backend.known_locale_names/0 rounding is one of [:down, :up, :ceiling, :floor, :half_even, :half_up, :half_down]. The default is :half_even. Examples iex&gt; Cldr.Print.Backend.Number.Ordinal.plural_rule 0, &quot;fr&quot; :other iex&gt; Cldr.Print.Backend.Number.Ordinal.plural_rule 1, &quot;en&quot; :one"},{"ref":"Cldr.Print.Backend.Number.Ordinal.html#plural_rules/0","title":"Cldr.Print.Backend.Number.Ordinal.plural_rules/0","type":"function","doc":"Returns all the plural rules defined in CLDR."},{"ref":"Cldr.Print.Backend.Number.Ordinal.html#plural_rules_for/1","title":"Cldr.Print.Backend.Number.Ordinal.plural_rules_for/1","type":"function","doc":"Return the plural rules for a locale. Arguments locale is any locale returned by Cldr.Print.Backend.Locale.new!/1 or any locale_name returned by Cldr.Print.Backend.known_locale_names/0 The rules are returned in AST form after parsing."},{"ref":"Cldr.Print.Backend.Number.Ordinal.html#pluralize/3","title":"Cldr.Print.Backend.Number.Ordinal.pluralize/3","type":"function","doc":"Pluralize a number using ordinal plural rules and a substition map. Arguments number is an integer, float or Decimal or a Range.t{}. When a range, The is that in any usage, the start value is strictly less than the end value, and that no values are negative. Results for any cases that do not meet these criteria are undefined. locale is any locale returned by Cldr.Print.Backend.Locale.new!/1 or any locale_name returned by Cldr.Print.Backend.known_locale_names/0 substitutions is a map that maps plural keys to a string. The valid substitution keys are :zero, :one, :two, :few, :many and :other. See also Cldr.Print.Backend.Number.Ordinal.Ordinal.plural_rule/3. Examples iex&gt; Cldr.Print.Backend.Number.Ordinal.pluralize 1, &quot;en&quot;, %{one: &quot;one&quot;} &quot;one&quot; iex&gt; Cldr.Print.Backend.Number.Ordinal.pluralize 2, &quot;en&quot;, %{one: &quot;one&quot;} nil iex&gt; Cldr.Print.Backend.Number.Ordinal.pluralize 2, &quot;en&quot;, %{one: &quot;one&quot;, two: &quot;two&quot;} &quot;two&quot; iex&gt; Cldr.Print.Backend.Number.Ordinal.pluralize 22, &quot;en&quot;, %{one: &quot;one&quot;, two: &quot;two&quot;, other: &quot;other&quot;} &quot;two&quot; iex&gt; Cldr.Print.Backend.Number.Ordinal.pluralize Decimal.new(1), &quot;en&quot;, %{one: &quot;one&quot;} &quot;one&quot; iex&gt; Cldr.Print.Backend.Number.Ordinal.pluralize Decimal.new(2), &quot;en&quot;, %{one: &quot;one&quot;} nil iex&gt; Cldr.Print.Backend.Number.Ordinal.pluralize Decimal.new(2), &quot;en&quot;, %{one: &quot;one&quot;, two: &quot;two&quot;} &quot;two&quot; iex&gt; Cldr.Print.Backend.Number.Ordinal.pluralize 1..10, &quot;ar&quot;, %{one: &quot;one&quot;, few: &quot;few&quot;, other: &quot;other&quot;} &quot;other&quot; iex&gt; Cldr.Print.Backend.Number.Ordinal.pluralize 1..10, &quot;en&quot;, %{one: &quot;one&quot;, few: &quot;few&quot;, other: &quot;other&quot;} &quot;other&quot;"},{"ref":"Cldr.Print.Backend.Number.PluralRule.Range.html","title":"Cldr.Print.Backend.Number.PluralRule.Range","type":"module","doc":"Implements plural rules for ranges"},{"ref":"Cldr.Print.Backend.Number.PluralRule.Range.html#plural_rule/3","title":"Cldr.Print.Backend.Number.PluralRule.Range.plural_rule/3","type":"function","doc":"Returns a final plural type for a start-of-range plural type, an end-of-range plural type and a locale. Arguments first is a plural type for the start of a range last is a plural type for the end of a range locale is any Cldr.LanguageTag.t or a language name (not locale name) Example iex&gt; Cldr.Print.Backend.Number.PluralRule.Range.plural_rule :other, :few, &quot;ar&quot; :few"},{"ref":"Cldr.Print.Backend.Number.Symbol.html","title":"Cldr.Print.Backend.Number.Symbol","type":"module","doc":""},{"ref":"Cldr.Print.Backend.Number.Symbol.html#all_decimal_symbols/0","title":"Cldr.Print.Backend.Number.Symbol.all_decimal_symbols/0","type":"function","doc":"Returns a list of all decimal symbols defined by the locales configured in this backend as a list."},{"ref":"Cldr.Print.Backend.Number.Symbol.html#all_decimal_symbols_class/0","title":"Cldr.Print.Backend.Number.Symbol.all_decimal_symbols_class/0","type":"function","doc":"Returns a list of all decimal symbols defined by the locales configured in this backend as a string. This string can be used as a character class when builing a regular expression."},{"ref":"Cldr.Print.Backend.Number.Symbol.html#all_grouping_symbols/0","title":"Cldr.Print.Backend.Number.Symbol.all_grouping_symbols/0","type":"function","doc":"Returns a list of all grouping symbols defined by the locales configured in this backend as a list."},{"ref":"Cldr.Print.Backend.Number.Symbol.html#all_grouping_symbols_class/0","title":"Cldr.Print.Backend.Number.Symbol.all_grouping_symbols_class/0","type":"function","doc":"Returns a list of all grouping symbols defined by the locales configured in this backend as a string. This string can be used as a character class when builing a regular expression."},{"ref":"Cldr.Print.Backend.Number.Symbol.html#number_symbols_for/1","title":"Cldr.Print.Backend.Number.Symbol.number_symbols_for/1","type":"function","doc":"Returns a map of Cldr.Number.Symbol.t structs of the number symbols for each of the number systems of a locale. Options locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/. The default is Cldr.Print.Backend.get_locale/0. Example: iex&gt; Cldr.Print.Backend.Number.Symbol.number_symbols_for(&quot;th&quot;) {:ok, %{ latn: %Cldr.Number.Symbol{ decimal: &quot;.&quot;, exponential: &quot;E&quot;, group: &quot;,&quot;, infinity: &quot;∞&quot;, list: &quot;;&quot;, minus_sign: &quot;-&quot;, nan: &quot;NaN&quot;, per_mille: &quot;‰&quot;, percent_sign: &quot;%&quot;, plus_sign: &quot;+&quot;, superscripting_exponent: &quot;×&quot;, time_separator: &quot;:&quot; }, thai: %Cldr.Number.Symbol{ decimal: &quot;.&quot;, exponential: &quot;E&quot;, group: &quot;,&quot;, infinity: &quot;∞&quot;, list: &quot;;&quot;, minus_sign: &quot;-&quot;, nan: &quot;NaN&quot;, per_mille: &quot;‰&quot;, percent_sign: &quot;%&quot;, plus_sign: &quot;+&quot;, superscripting_exponent: &quot;×&quot;, time_separator: &quot;:&quot; } }}"},{"ref":"Cldr.Print.Backend.Number.Symbol.html#number_symbols_for/2","title":"Cldr.Print.Backend.Number.Symbol.number_symbols_for/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Number.System.html","title":"Cldr.Print.Backend.Number.System","type":"module","doc":""},{"ref":"Cldr.Print.Backend.Number.System.html#number_system_for/2","title":"Cldr.Print.Backend.Number.System.number_system_for/2","type":"function","doc":"Returns the actual number system from a number system type. locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Locale.new!/1 system_name is any number system name returned by Cldr.known_number_systems/0 or a number system type returned by Cldr.known_number_system_types/0 This function will decode a number system type into the actual number system. If the number system provided can&#39;t be decoded it is returned as is. Examples iex&gt; Cldr.Number.System.number_system_for &quot;th&quot;, :latn, TestBackend.Cldr {:ok, %{digits: &quot;0123456789&quot;, type: :numeric}} iex&gt; Cldr.Number.System.number_system_for &quot;en&quot;, :default, TestBackend.Cldr {:ok, %{digits: &quot;0123456789&quot;, type: :numeric}} iex&gt; Cldr.Number.System.number_system_for &quot;he&quot;, :traditional, TestBackend.Cldr {:ok, %{rules: &quot;hebrew&quot;, type: :algorithmic}} iex&gt; Cldr.Number.System.number_system_for &quot;en&quot;, :finance, TestBackend.Cldr { :error, {Cldr.UnknownNumberSystemError, &quot;The number system :finance is unknown for the locale named \\&quot;en\\&quot;. Valid number systems are %{default: :latn, native: :latn}&quot;} } iex&gt; Cldr.Number.System.number_system_for &quot;en&quot;, :native, TestBackend.Cldr {:ok, %{digits: &quot;0123456789&quot;, type: :numeric}}"},{"ref":"Cldr.Print.Backend.Number.System.html#number_system_names_for/1","title":"Cldr.Print.Backend.Number.System.number_system_names_for/1","type":"function","doc":"Returns the number systems available for a locale or {:error, message} if the locale is not known. locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/1 Examples iex&gt; Cldr.Print.Backend.Number.System.number_system_names_for &quot;en&quot; {:ok, [:latn]} iex&gt; Cldr.Print.Backend.Number.System.number_system_names_for &quot;zz&quot; {:error, {Cldr.UnknownLocaleError, &quot;The locale \\&quot;zz\\&quot; is not known.&quot;}}"},{"ref":"Cldr.Print.Backend.Number.System.html#number_system_names_for!/1","title":"Cldr.Print.Backend.Number.System.number_system_names_for!/1","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Number.System.html#number_system_types_for/1","title":"Cldr.Print.Backend.Number.System.number_system_types_for/1","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Number.System.html#number_systems_for/1","title":"Cldr.Print.Backend.Number.System.number_systems_for/1","type":"function","doc":"Returns the number systems available for a locale or {:error, message} if the locale is not known. locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/1 Examples iex&gt; Cldr.Print.Backend.Number.System.number_systems_for &quot;en&quot; {:ok, %{default: :latn, native: :latn}} iex&gt; Cldr.Print.Backend.Number.System.number_systems_for &quot;th&quot; {:ok, %{default: :latn, native: :thai}} iex&gt; Cldr.Print.Backend.Number.System.number_systems_for &quot;zz&quot; {:error, {Cldr.UnknownLocaleError, &quot;The locale \\&quot;zz\\&quot; is not known.&quot;}}"},{"ref":"Cldr.Print.Backend.Number.System.html#number_systems_for!/1","title":"Cldr.Print.Backend.Number.System.number_systems_for!/1","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Number.System.html#number_systems_like/2","title":"Cldr.Print.Backend.Number.System.number_systems_like/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Number.System.html#system_name_from/2","title":"Cldr.Print.Backend.Number.System.system_name_from/2","type":"function","doc":"Returns a number system name for a given locale and number system reference. system_name is any number system name returned by Cldr.Print.Backend.known_number_systems/0 or a number system type returned by Cldr.Print.Backend.known_number_system_types/0 locale is any valid locale name returned by Cldr.Print.Backend.known_locale_names/0 or a Cldr.LanguageTag struct returned by Cldr.Print.Backend.Locale.new!/1 Number systems can be references in one of two ways: As a number system type such as :default, :native, :traditional and :finance. This allows references to a number system for a locale in a consistent fashion for a given use WIth the number system name directly, such as :latn, :arab or any of the other 70 or so This function dereferences the supplied system_name and returns the actual system name. Examples ex&gt; Cldr.Print.Backend.Number.System.system_name_from(:default, &quot;en&quot;) {:ok, :latn} iex&gt; Cldr.Print.Backend.Number.System.system_name_from(&quot;latn&quot;, &quot;en&quot;) {:ok, :latn} iex&gt; Cldr.Print.Backend.Number.System.system_name_from(:native, &quot;en&quot;) {:ok, :latn} iex&gt; Cldr.Print.Backend.Number.System.system_name_from(:nope, &quot;en&quot;) { :error, {Cldr.UnknownNumberSystemError, &quot;The number system :nope is unknown&quot;} } Note that return value is not guaranteed to be a valid number system for the given locale as demonstrated in the third example."},{"ref":"Cldr.Print.Backend.Number.System.html#to_system/2","title":"Cldr.Print.Backend.Number.System.to_system/2","type":"function","doc":"Converts a number into the representation of a non-latin number system. This function converts numbers to a known number system only, it does not provide number formatting. number is a float, integer or Decimal system_name is any number system name returned by Cldr.known_number_systems/0 or a number system type returned by Cldr.known_number_system_types/0 There are two types of number systems in CLDR: :numeric in which the number system defines a direct mapping between the latin digits 0..9 into a the number system equivalent. In this case, to_system/2 invokes Cldr.Number.Transliterate.transliterate_digits/3 for the given number. :algorithmic in which the number system does not have the same structure as the :latn number system and therefore the conversion is done algorithmically. For CLDR the algorithm is implemented through Cldr.Rbnf rulesets. These rulesets are considered by CLDR to be less rigorous than the :numeric number systems and caution and testing for a specific use case is recommended. Examples iex&gt; Cldr.Print.Backend.Number.System.to_system 123456, :hebr {:ok, &quot;ק׳׳ת׳&quot;} iex&gt; Cldr.Print.Backend.Number.System.to_system 123, :hans {:ok, &quot;一百二十三&quot;} iex&gt; Cldr.Print.Backend.Number.System.to_system 123, :hant {:ok, &quot;一百二十三&quot;} iex&gt; Cldr.Print.Backend.Number.System.to_system 123, :hansfin {:ok, &quot;壹佰贰拾叁&quot;}"},{"ref":"Cldr.Print.Backend.Number.System.html#to_system!/2","title":"Cldr.Print.Backend.Number.System.to_system!/2","type":"function","doc":"Converts a number into the representation of a non-latin number system. Returns a converted string or raises on error. number is a float, integer or Decimal system_name is any number system name returned by Cldr.Print.Backend.known_number_systems/0 or a number system type returned by Cldr.Print.Backend.known_number_system_types/0 See Cldr.Print.Backend.Number.System.to_system/2 for further information. Examples iex&gt; Cldr.Print.Backend.Number.System.to_system! 123, :hans &quot;一百二十三&quot; iex&gt; Cldr.Print.Backend.Number.System.to_system! 123, :hant &quot;一百二十三&quot; iex&gt; Cldr.Print.Backend.Number.System.to_system! 123, :hansfin &quot;壹佰贰拾叁&quot;"},{"ref":"Cldr.Print.Backend.Number.Transliterate.html","title":"Cldr.Print.Backend.Number.Transliterate","type":"module","doc":"Transliteration for digits and separators. Transliterating a string is an expensive business. First the string has to be exploded into its component graphemes. Then for each grapheme we have to map to the equivalent in the other {locale, number_system}. Then we have to reassemble the string. Effort is made to short circuit where possible. Transliteration is not required for any {locale, number_system} that is the same as {&quot;en&quot;, &quot;latn&quot;} since the implementation uses this combination for the placeholders during formatting already. When short circuiting is possible (typically the en-* locales with &quot;latn&quot; number_system - the total number of short circuited locales is 211 of the 537 in CLDR) the overall number formatting is twice as fast than when formal transliteration is required. Configuring precompilation of digit transliterations This module includes Cldr.Number.Transliterate.transliterate_digits/3 which transliterates digits between number systems. For example from :arabic to :latn. Since generating a transliteration map is slow, pairs of transliterations can be configured so that the transliteration map is created at compile time and therefore speeding up transliteration at run time. To configure these transliteration pairs, add the to the use Cldr configuration in a backend module: defmodule MyApp.Cldr do use Cldr, precompile_transliterations: [{:latn, :arab}, {:arab, :thai}] end end Where each tuple in the list configures one transliteration map. In this example, two maps are configured: from :latn to :thai and from :arab to :thai. A list of configurable number systems is returned by Cldr.Number.System.systems_with_digits/0. If a transliteration is requested between two number pairs that have not been configured for precompilation, a warning is logged."},{"ref":"Cldr.Print.Backend.Number.Transliterate.html#transliterate/3","title":"Cldr.Print.Backend.Number.Transliterate.transliterate/3","type":"function","doc":"Transliterates from latin digits to another number system&#39;s digits. Transliterates the latin digits 0..9 to their equivalents in another number system. Also transliterates the decimal and grouping separators as well as the plus, minus and exponent symbols. Any other character in the string will be returned &quot;as is&quot;. Arguments sequence is the string to be transliterated. locale is any known locale, defaulting to Cldr.Print.Backend.get_locale/0. number_system is any known number system. If expressed as a string it is the actual name of a known number system. If epressed as an atom it is used as a key to look up a number system for the locale (the usual keys are :default and :native but :traditional and :finance are also part of the standard). See Cldr.Print.Backend.Number.System.number_systems_for/1 for a locale to see what number system types are defined. The default is :default. For available number systems see Cldr.Number.System.number_systems/0 and Cldr.Print.Backend.Number.System.number_systems_for/1. Also see Cldr.Print.Backend.Number.Symbol.number_symbols_for/1. Examples iex&gt; Cldr.Print.Backend.Number.Transliterate.transliterate(&quot;123556&quot;) &quot;123556&quot; iex&gt; Cldr.Print.Backend.Number.Transliterate.transliterate(&quot;123,556.000&quot;, &quot;fr&quot;, :default) &quot;123 556,000&quot; iex&gt; Cldr.Print.Backend.Number.Transliterate.transliterate(&quot;123556&quot;, &quot;th&quot;, :default) &quot;123556&quot; iex&gt; Cldr.Print.Backend.Number.Transliterate.transliterate(&quot;123556&quot;, &quot;th&quot;, &quot;thai&quot;) &quot;๑๒๓๕๕๖&quot; iex&gt; Cldr.Print.Backend.Number.Transliterate.transliterate(&quot;123556&quot;, &quot;th&quot;, :native) &quot;๑๒๓๕๕๖&quot; iex&gt; Cldr.Print.Backend.Number.Transliterate.transliterate(&quot;Some number is: 123556&quot;, &quot;th&quot;, &quot;thai&quot;) &quot;Some number is: ๑๒๓๕๕๖&quot;"},{"ref":"Cldr.Print.Backend.Number.Transliterate.html#transliterate!/3","title":"Cldr.Print.Backend.Number.Transliterate.transliterate!/3","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Number.Transliterate.html#transliterate_digits/3","title":"Cldr.Print.Backend.Number.Transliterate.transliterate_digits/3","type":"function","doc":"Transliterates digits from one number system to another number system digits is binary representation of a number from_system and to_system are number system names in atom form. See Cldr.Number.System.systems_with_digits/0 for available number systems. Example iex&gt; Cldr.Print.Backend.Number.Transliterate.transliterate_digits &quot;٠١٢٣٤٥٦٧٨٩&quot;, :arab, :latn &quot;0123456789&quot;"},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html","title":"Cldr.Print.Backend.Rbnf.NumberSystem","type":"module","doc":"Functions to implement the number system rule-based-number-format rules of CLDR. These rules are defined only on the &quot;root&quot; locale and represent specialised number formatting. The standard public API for RBNF is via the Cldr.Number.to_string/2 function. The functions on this module are defined at compile time based upon the RBNF rules defined in the Unicode CLDR data repository. Available rules are identified by: iex&gt; Cldr.Print.Backend.Rbnf.NumberSystem.rule_sets(&quot;root&quot;) [:tamil, :roman_upper, :roman_lower, :hebrew_item, :hebrew_0_99, :hebrew, :greek_upper, :greek_lower, :georgian, :ethiopic_p1, :ethiopic, :cyrillic_lower_1_10, :cyrillic_lower, :armenian_upper, :armenian_lower] A rule can then be invoked on an available rule_set. For example iex&gt; Cldr.Print.Backend.Rbnf.NumberSystem.roman_upper(123, &quot;root&quot;) &quot;CXXIII&quot; This call is equivalent to the call through the public API of: iex&gt; Cldr.Print.Backend.Number.to_string(123, format: :roman) {:ok, &quot;CXXIII&quot;}"},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#all_rule_sets/0","title":"Cldr.Print.Backend.Rbnf.NumberSystem.all_rule_sets/0","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#armenian_lower/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.armenian_lower/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#armenian_upper/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.armenian_upper/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#cyrillic_lower/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.cyrillic_lower/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#cyrillic_lower_1_10/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.cyrillic_lower_1_10/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#cyrillic_lower_final/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.cyrillic_lower_final/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#cyrillic_lower_post/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.cyrillic_lower_post/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#cyrillic_lower_thousands/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.cyrillic_lower_thousands/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#ethiopic/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.ethiopic/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#ethiopic_p/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.ethiopic_p/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#ethiopic_p1/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.ethiopic_p1/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#ethiopic_p2/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.ethiopic_p2/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#ethiopic_p3/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.ethiopic_p3/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#georgian/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.georgian/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#greek_lower/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.greek_lower/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#greek_numeral_majuscules/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.greek_numeral_majuscules/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#greek_numeral_minuscules/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.greek_numeral_minuscules/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#greek_upper/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.greek_upper/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#hebrew/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.hebrew/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#hebrew_0_99/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.hebrew_0_99/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#hebrew_item/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.hebrew_item/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#hebrew_thousands/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.hebrew_thousands/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#roman_lower/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.roman_lower/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#roman_upper/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.roman_upper/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#rule_sets/1","title":"Cldr.Print.Backend.Rbnf.NumberSystem.rule_sets/1","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#tamil/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.tamil/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.NumberSystem.html#tamil_thousands/2","title":"Cldr.Print.Backend.Rbnf.NumberSystem.tamil_thousands/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Ordinal.html","title":"Cldr.Print.Backend.Rbnf.Ordinal","type":"module","doc":"Functions to implement the ordinal rule-based-number-format rules of CLDR. As CLDR notes, the data is incomplete or non-existent for many languages. It is considered complete for English however. The standard public API for RBNF is via the Cldr.Number.to_string/2 function. The functions on this module are defined at compile time based upon the RBNF rules defined in the Unicode CLDR data repository. Available rules are identified by: iex&gt; Cldr.Print.Backend.Rbnf.Ordinal.rule_sets(&quot;en&quot;) [:digits_ordinal] A rule can then be invoked on an available rule_set. For example iex&gt; Cldr.Print.Backend.Rbnf.Ordinal.digits_ordinal(123, &quot;en&quot;) &quot;123rd&quot; This call is equivalent to the call through the public API of: iex&gt; Cldr.Print.Backend.Number.to_string(123, format: :ordinal) {:ok, &quot;123rd&quot;}"},{"ref":"Cldr.Print.Backend.Rbnf.Ordinal.html#all_rule_sets/0","title":"Cldr.Print.Backend.Rbnf.Ordinal.all_rule_sets/0","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Ordinal.html#digits_ordinal/2","title":"Cldr.Print.Backend.Rbnf.Ordinal.digits_ordinal/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Ordinal.html#rule_sets/1","title":"Cldr.Print.Backend.Rbnf.Ordinal.rule_sets/1","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html","title":"Cldr.Print.Backend.Rbnf.Spellout","type":"module","doc":"Functions to implement the spellout rule-based-number-format rules of CLDR. As CLDR notes, the data is incomplete or non-existent for many languages. It is considered complete for English however. The standard public API for RBNF is via the Cldr.Number.to_string/2 function. The functions on this module are defined at compile time based upon the RBNF rules defined in the Unicode CLDR data repository. Available rules are identified by: iex&gt; Cldr.Print.Backend.Rbnf.Spellout.rule_sets(&quot;en&quot;) [:spellout_ordinal_verbose, :spellout_ordinal, :spellout_numbering_year, :spellout_numbering_verbose, :spellout_numbering, :spellout_cardinal_verbose, :spellout_cardinal] A rule can then be invoked on an available rule_set. For example: iex&gt; Cldr.Print.Backend.Rbnf.Spellout.spellout_ordinal(123, &quot;en&quot;) &quot;one hundred twenty-third&quot; This call is equivalent to the call through the public API of: iex&gt; Cldr.Print.Backend.Number.to_string(123, format: :spellout) {:ok, &quot;one hundred twenty-three&quot;}"},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#2d_year/2","title":"Cldr.Print.Backend.Rbnf.Spellout.2d_year/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#all_rule_sets/0","title":"Cldr.Print.Backend.Rbnf.Spellout.all_rule_sets/0","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#and/2","title":"Cldr.Print.Backend.Rbnf.Spellout.and/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#and_o/2","title":"Cldr.Print.Backend.Rbnf.Spellout.and_o/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#commas/2","title":"Cldr.Print.Backend.Rbnf.Spellout.commas/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#commas_o/2","title":"Cldr.Print.Backend.Rbnf.Spellout.commas_o/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#rule_sets/1","title":"Cldr.Print.Backend.Rbnf.Spellout.rule_sets/1","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#spellout_cardinal/2","title":"Cldr.Print.Backend.Rbnf.Spellout.spellout_cardinal/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#spellout_cardinal_verbose/2","title":"Cldr.Print.Backend.Rbnf.Spellout.spellout_cardinal_verbose/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#spellout_numbering/2","title":"Cldr.Print.Backend.Rbnf.Spellout.spellout_numbering/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#spellout_numbering_verbose/2","title":"Cldr.Print.Backend.Rbnf.Spellout.spellout_numbering_verbose/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#spellout_numbering_year/2","title":"Cldr.Print.Backend.Rbnf.Spellout.spellout_numbering_year/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#spellout_ordinal/2","title":"Cldr.Print.Backend.Rbnf.Spellout.spellout_ordinal/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#spellout_ordinal_verbose/2","title":"Cldr.Print.Backend.Rbnf.Spellout.spellout_ordinal_verbose/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#th/2","title":"Cldr.Print.Backend.Rbnf.Spellout.th/2","type":"function","doc":""},{"ref":"Cldr.Print.Backend.Rbnf.Spellout.html#tieth/2","title":"Cldr.Print.Backend.Rbnf.Spellout.tieth/2","type":"function","doc":""},{"ref":"readme.html","title":"Cldr Print","type":"extras","doc":"Cldr Print Provides printf and sprintf functions for Elixir that are largely compatible with the C versions."},{"ref":"readme.html#getting-started","title":"Cldr Print - Getting Started","type":"extras","doc":"Cldr.Print.printf/3, Cldr.Print.sprintf/3 and Cldr.Print.lprintf/3 operate on a format string and a list of arguments to produce a formatted output. The differences are: Cldr.Print.printf/3 outputs to a device specified under the option key :device with :stdout as the default Cldr.Print.sprintf/3 returns an {:ok, string} tuple or an {:error, {exception, reason}} tuple. Cldr.Print.lprintf/3 returns an {:ok, io_list} tuple or an {:error, {exception, reason}} tuple. There are also ! bang versions of these functions which will return the result unwrapped or raise an exception if there is an error."},{"ref":"readme.html#examples","title":"Cldr Print - Examples","type":"extras","doc":"Here are some examples to help get started if you are unfamiliar with the C versions of these functions. Controlling Integer Width The %3d specifier is used with integers where the 3 represents the width in graphemes of the final formatted string. These example define a minimum width of three spaces which, by default, will be right-justified: Function callResult printf!(&quot;%3d&quot;, 0)0 printf!(&quot;%3d&quot;, 123456789)123456789 printf!(&quot;%3d&quot;, -10)-10 printf!(&quot;%3d&quot;, -123456789)-123456789 Left-justifying with the - flag To left-justify an integer add a minus sign - after the % symbol: Function callResult printf!(&quot;%-3d&quot;, 0)0 printf!(&quot;%-3d&quot;, 123456789)123456789 printf!(&quot;%-3d&quot;, -10)-10 printf!(&quot;%-3d&quot;, -123456789)-123456789 Zero-fill flag To zero-fill the result add a zero 0 after the % symbol: Function callResult printf(&quot;%03d&quot;, 0)000 printf(&quot;%03d&quot;, 1)001 printf(&quot;%03d&quot;, 123456789)123456789 printf(&quot;%03d&quot;, -10)-10 printf(&quot;%03d&quot;, -123456789)-123456789 Integer formatting summary Here are some further examples including a minimum width specification, left-justified, zero-filled, as well as a plus sign for positive numbers. DescriptionFunction callResult At least five wideprintf(&quot;&#39;%5d&#39;&quot;, 10)&#39; 10&#39; At least five-wide, left-justifiedprintf(&quot;&#39;%-5d&#39;&quot;, 10)&#39;10 &#39; At least five-wide, zero-filledprintf(&quot;&#39;%05d&#39;&quot;, 10)&#39;00010&#39; At least five-wide, with a plus signprintf(&quot;&#39;%+5d&#39;&quot;, 10)&#39; +10&#39; Five-wide, plus sign, left-justifiedprintf(&quot;&#39;%-+5d&#39;&quot;, 10)&#39;+10 &#39; Floating Point Formatting Here are several examples showing how to format floating-point numbers: DescriptionFunction callResult Print one position after the decimalprintf(&quot;&#39;%.1f&#39;&quot;, 10.3456)&#39;10.3&#39; Two positions after the decimalprintf(&quot;&#39;%.2f&#39;&quot;, 10.3456)&#39;10.35&#39; Eight-wide, two positions after the decimalprintf(&quot;&#39;%8.2f&#39;&quot;, 10.3456)&#39; 10.35&#39; Eight-wide, four positions after the decimalprintf(&quot;&#39;%8.4f&#39;&quot;, 10.3456)&#39; 10.3456&#39; Eight-wide, two positions after the decimal, zero-filledprintf(&quot;&#39;%08.2f&#39;&quot;, 10.3456)&#39;00010.35&#39; Eight-wide, two positions after the decimal, left-justifiedprintf(&quot;&#39;%-8.2f&#39;&quot;, 10.3456)&#39;10.35 &#39; Printing a much larger number with that same formatprintf(&quot;&#39;%-8.2f&#39;&quot;,101234567.3456)&#39;101234567.35&#39; String Formatting Here are some examples of string formatting: DescriptionFunction callResult A simple stringprintf(&quot;&#39;%s&#39;&quot;, &quot;Hello&quot;)&#39;Hello&#39; A string with a minimum lengthprintf(&quot;&#39;%10s&#39;&quot;, &quot;Hello&quot;)&#39; Hello&#39; Minimum length, left-justifiedprintf(&quot;&#39;%-10s&#39;&quot;, &quot;Hello&quot;)&#39;Hello &#39;"},{"ref":"readme.html#format-specification","title":"Cldr Print - Format Specification","type":"extras","doc":"The format is a string which contains two types of objects: plain characters, which are simply copied to standard output and format specifications, each of which causes printing of the next successive argument. Each format specification is introduced by the percent character (%). The remainder of the format specification includes, in the following order: Optional format flags Optional field width Optional precision Required format type The can be represented as: %[flags][width][.precision]format_type Format flags Zero or more of the following flags: FlagDescription #A # character specifying that the value should be printed in an alternate form. For b, c, d, s and u formats, this option has no effect. For the o formats the precision of the number is increased to force the first character of the output string to a zero. For the x (X) format, a non-zero result has the string 0x (0X) prepended to it. For a, A, e, E, f, F, g and G formats, the result will always contain a decimal point, even if no digits follow the point (normally, a decimal point only appears in the results of those formats if a digit follows the decimal point). For g and G formats, trailing zeros are not removed from the result as they would otherwise be. -A minus sign `-&#39; which specifies left adjustment of the output in the indicated field. +A + character specifying that there should always be a sign placed before the number when using signed formats. spaceA space character specifying that a blank should be left before a positive number for a signed format. A + overrides a space if both are used. 0A zero 0 character indicating that zero-padding should be used rather than blank-padding. A - overrides a 0 if both are used. Is not applied for o, x, X formats. &#39;Formats a number with digit grouping applied. The group size and grouping character are determined based upon the current processes locale or the :locale option to printf/3 if provided. Is not applied for formats o, x, X formats. IFormats a number using the native number system digits of the current processes locale or the :locale option to printf/3 if provided. The option :number_system if provided takes precedence over this flag. Field Width An optional digit string specifying a field width; if the output string has fewer bytes than the field width it will be blank-padded on the left (or right, if the left-adjustment indicator has been given) to make up the field width (note that a leading zero is a flag, but an embedded zero is part of a field width). Precision An optional period, ., followed by an optional digit string giving a precision which specifies the number of digits to appear after the decimal point, for e and f formats, or the maximum number of graphemes to be printed from a string. If the digit string is missing, the precision is treated as zero. Format Type A character which indicates the type of format to use (one of diouxXfFeEgGaAs). The uppercase formats differ from their lowercase counterparts only in that the output of the former is entirely in uppercase. FormatDescription diouXxThe argument is printed as a signed decimal (d or i), unsigned octal, unsigned decimal, or unsigned hexadecimal (X or x), respectively. fFThe argument is printed in the style [-]ddd.ddd where the number of d&#39;s after the decimal point is equal to the precision specification for the argument. If the precision is missing, 6 digits are given; if the precision is explicitly 0, no digits and no decimal point are printed. The values infinity and NaN are printed as inf&#39; andnan&#39;, respectively. eEThe argument is printed in the style e [-d.ddd+-dd] where there is one digit before the decimal point and the number after is equal to the precision specification for the argument; when the precision is missing, 6 digits are produced. The values infinity and NaN are printed as inf and nan, respectively. gGThe argument is printed in style f or e (or in style E for a G format code), with the precision specifying the number of significant digits. The style used depends on the value converted: style e will be used only if the exponent resulting from the conversion is less than -4 or greater than the precision. Trailing zeroes are removed from the result; a decimal point appears only if it is followed by a digit. aAThe argument is printed in style [-h.hhh+-pd] where there is one digit before the hexadecimal point and the number after is equal to the precision specification for the argument; when the precision is missing, enough digits are produced to convey the argument&#39;s exact double-precision floating-point representation. The values infinity and NaN are printed as inf and nan, respectively. sGraphemes from the string argument are printed until the end is reached or until the number of graphemes indicated by the precision specification is reached; however if the precision is 0 or missing, the string is printed entirely. %Print a %; no argument is used. Notes The grouping separator, decimal point and exponent characters are defined in the current process&#39;s locale or as specified in the :locale option to printf/3. In no case does a non-existent or small field width cause truncation of a field; padding takes place only if the specified field width exceeds the actual width."},{"ref":"readme.html#todo","title":"Cldr Print - Todo","type":"extras","doc":"[ ] Formats a and A aren&#39;t implemented [ ] The # is not validated for a, A, e, E, f, F, g and G formats. There seems to be some inconsistent implementations around that need further investigation [ ] The space flag is not implemented"},{"ref":"readme.html#installation","title":"Cldr Print - Installation","type":"extras","doc":"def deps do [ {:ex_cldr_print, &quot;~&gt; 0.2.0&quot;} ] end The documentation can be found at https://hexdocs.pm/ex_cldr_print."},{"ref":"license.html","title":"License","type":"extras","doc":"License Copyright 2019 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License."},{"ref":"changelog.html","title":"Changelog for Cldr Print v0.2.0","type":"extras","doc":"Changelog for Cldr Print v0.2.0 This is the changelog for Cldr Print v0.2.0 released on March 28th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Updates to CLDR version 35.0.0 released on March 27th 2019. Changelog for Cldr Print v0.1.0 This is the changelog for Cldr Print v0.1.0 released on March 4th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Initial Release."}]